<?php
/**
 * Popular Trips Section options
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 */

// Add Popular Trips section
$wp_customize->add_section( 'tale_travel_pro_popular_trips_section', array(
	'title'             => esc_html__( 'Popular Trips','tale-travel-pro' ),
	'description'       => esc_html__( 'Popular Trips Section options.', 'tale-travel-pro' ),
	'panel'             => 'tale_travel_pro_front_page_panel',
) );

// Popular Trips content enable control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_section_enable]', array(
	'default'			=> 	$options['popular_trips_section_enable'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tale_Travel_Pro_Switch_Control( $wp_customize, 'tale_travel_pro_theme_options[popular_trips_section_enable]', array(
	'label'             => esc_html__( 'Popular Trips Section Enable', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'on_off_label' 		=> tale_travel_pro_switch_options(),
) ) );

// popular destination title setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_title]', array(
	'default'			=> $options['popular_trips_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[popular_trips_title]', array(
	'label'           	=> esc_html__( 'Title', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_popular_trips_section',
	'active_callback' 	=> 'tale_travel_pro_is_popular_trips_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tale_travel_pro_theme_options[popular_trips_title]', array(
		'selector'            => '#most-viewed-posts .section-header h2.section-title',
		'settings'            => 'tale_travel_pro_theme_options[popular_trips_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tale_travel_pro_popular_trips_title_partial',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_btn_title]', array(
	'default'			=> $options['popular_trips_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[popular_trips_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_popular_trips_section',
	'active_callback' 	=> 'tale_travel_pro_is_popular_trips_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tale_travel_pro_theme_options[popular_trips_btn_title]', array(
		'selector'            => '#most-viewed-posts .section-header a.more-link',
		'settings'            => 'tale_travel_pro_theme_options[popular_trips_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tale_travel_pro_popular_trips_btn_title_partial',
    ) );
}

// popular destination read more setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[popular_trips_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_popular_trips_section',
	'active_callback' 	=> 'tale_travel_pro_is_popular_trips_section_enable',
	'type'				=> 'url',
) );

// Popular Trips content type control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_content_type]', array(
	'default'          	=> $options['popular_trips_content_type'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[popular_trips_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tale_travel_pro_is_popular_trips_section_enable',
	'choices'			=> tale_travel_pro_popular_trips_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_count]', array(
	'default'          	=> $options['popular_trips_count'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_number_range',
	'validate_callback' => 'tale_travel_pro_validate_popular_trips_count',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[popular_trips_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'tale-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'active_callback'   => 'tale_travel_pro_is_popular_trips_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i=1; $i <= $options['popular_trips_count']; $i++ ) { 
	// popular_trips pages drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[popular_trips_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_popular_trips_section',
		'choices'			=> tale_travel_pro_page_choices(),
		'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_page_enable',
	) ) );

	// popular_trips posts drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[popular_trips_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_popular_trips_section',
		'choices'			=> tale_travel_pro_post_choices(),
		'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_post_enable',
	) ) );

	// popular_trips trips drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[popular_trips_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[popular_trips_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_popular_trips_section',
		'choices'			=> tale_travel_pro_trip_choices(),
		'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[popular_trips_content_category]', array(
	'sanitize_callback' => 'tale_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[popular_trips_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tale-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Popular Trips selected no of posts will be shown from selected category', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[popular_trips_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[popular_trips_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[popular_trips_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[popular_trips_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[popular_trips_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[popular_trips_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_popular_trips_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_popular_trips_section_content_destination_enable'
) ) );

